# Table of Contents

- [obsolescence-risk-management-monitor-mitigation](<./obsolescence-risk-management-monitor-mitigation.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Step 5: Monitor, Measure, and Report Risk Mitigation Efforts](<./Step-5-Monitor-Measure-and-Report-Risk-Mitigation-Efforts.md>)
  - [Monitor and Measure Progress](<./Step-5-Monitor-Measure-and-Report-Risk-Mitigation-Efforts/Monitor-and-Measure-Progress.md>)
  - [Communicate and Foster Engagement](<./Step-5-Monitor-Measure-and-Report-Risk-Mitigation-Efforts/Communicate-and-Foster-Engagement.md>)
